# Contributors

## NIFTy8

- Andrija Kostic
- David Outland
- Gordian Edenhofer
- Jakob Roth
- Lukas Platz
- Margret Westerkamp
- Martin Reinecke
- Massin Guerdi
- Matteo Guardiani
- [Philipp Arras](https://philipp-arras.de)
- [Philipp Frank](http://www.ph-frank.de)
- Reimar Heinrich Leike
- [Torsten Enßlin](https://wwwmpa.mpa-garching.mpg.de/~ensslin/)
- Vincent Eberle


## NIFTy7

- Andrija Kostic
- Gordian Edenhofer
- Jakob Knollmüller
- Jakob Roth
- Lukas Platz
- Matteo Guardiani
- Martin Reinecke
- [Philipp Arras](https://philipp-arras.de)
- [Philipp Frank](http://www.ph-frank.de)
- Reimar Heinrich Leike
- Simon Ding
- Vincent Eberle


## NIFTy6

- Andrija Kostic
- Gordian Edenhofer
- Jakob Knollmüller
- Lukas Platz
- Martin Reinecke
- [Philipp Arras](https://philipp-arras.de)
- [Philipp Frank](http://www.ph-frank.de)
- Philipp Haim
- Reimar Heinrich Leike
- Rouven Lemmerz
- [Torsten Enßlin](https://wwwmpa.mpa-garching.mpg.de/~ensslin/)
- Vincent Eberle


## NIFTy5

- Christoph Lienhard
- Gordian Edenhofer
- Jakob Knollmüller
- Julia Stadler
- Julian Rüstig
- Lukas Platz
- Martin Reinecke
- Max-Niklas Newrzella
- Natalia
- [Philipp Arras](https://philipp-arras.de)
- [Philipp Frank](http://www.ph-frank.de)
- Philipp Haim
- Reimar Heinrich Leike
- Sebastian Hutschenreuter
- Silvan Streit
- [Torsten Enßlin](https://wwwmpa.mpa-garching.mpg.de/~ensslin/)


## NIFTy4

- Christoph Lienhard
- Jakob Knollmüller
- Lukas Platz
- Martin Reinecke
- Mihai Baltac
- [Philipp Arras](https://philipp-arras.de)
- [Philipp Frank](http://www.ph-frank.de)
- Reimar Heinrich Leike
- Silvan Streit
- [Torsten Enßlin](https://wwwmpa.mpa-garching.mpg.de/~ensslin/)


## NIFTy3

- Daniel Pumpe
- Jait Dixit
- Jakob Knollmüller
- Martin Reinecke
- Mihai Baltac
- Natalia
- [Philipp Arras](https://philipp-arras.de)
- [Philipp Frank](http://www.ph-frank.de)
- Reimar Heinrich Leike
- Matevz Sraml
- Theo Steininger
- csongor

## NIFTy2

- Jait Dixit
- Theo Steininger
- csongor


## NIFTy1

- Johannes Buchner
- Marco Selig
- Theo Steininger

